package com.zy.omp.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zy.omp.pojo.io.wechat.DeviceHistoryIO;
import com.zy.omp.mapper.LocationMapper;
import com.zy.omp.model.Location;
import com.zy.omp.model.LatestLocation;
import com.zy.omp.utils.BeanUtil;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 设备位置信息相关
 *
 * @author chenyi
 * Create on 2020/4/10
 */
@Service
public class LocationService extends ServiceImpl<LocationMapper, Location> {

    @Resource
    private LatestLocationService latestLocationService;

    /**
     * 保存位置信息
     */
    public void saveLocation(Location entity) {
        save(entity);
        //更新最新的位置信息
        QueryWrapper<LatestLocation> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("deviceId", entity.getDeviceId());
        LatestLocation latestLocation = BeanUtil.cast(entity, LatestLocation.class);
        latestLocationService.saveOrUpdate(latestLocation, queryWrapper);
    }

    /**
     * 获取设备的最新位置信息
     *
     * @param deviceId 设备ID
     */
    public LatestLocation getLatestLocation(String deviceId) {
        QueryWrapper<LatestLocation> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("deviceId", deviceId);
        return latestLocationService.getOne(queryWrapper);
    }

    /**
     * 查看设备历史轨迹
     *
     * @param io 查询入参
     */
    public List<Location> getHistory(DeviceHistoryIO io) {
        QueryWrapper<Location> queryWrapper = new QueryWrapper<>();
        queryWrapper.select("lonGcj", "latGcj", "uploadTime")
                .eq("deviceId", io.getDeviceId())
                .ge("uploadTime", io.getStartTime())
                .le("uploadTime", io.getEndTime())
                .orderByDesc("uploadTime");
        return baseMapper.selectList(queryWrapper);
    }

}
